      SUBROUTINE wat_tank 

        !!------------------------------------------------------------------
        !!                *** SUBROUTINE  wat_tank  ***
        !!
        !! ** Purpose : Compute properties of the water in the tank
        !!           
        !! ** Method  : Resolve simple mass conservation equations
        !!
        !! ** Arguments :
        !!
        !! ** Inputs / Ouputs : (global commons)
        !!
        !! ** External : 
        !!
        !! ** References :
        !!
        !! ** History :
        !!    v1: Max Thomas, Martin Vancoppenolle: initial coding in Norwich (2017) 
        !!
        !!------------------------------------------------------------------

      INCLUDE 'type.com'
      INCLUDE 'para.com'
      INCLUDE 'const.com'
      INCLUDE 'ice.com'
      INCLUDE 'thermo.com'
      INCLUDE 'bio.com'
      INCLUDE 'tank.com'

      ln_tank = .TRUE.
      ji = 1

!===============================================================================

      WRITE(numout,*) 
      WRITE(numout,*) ' * wat_tank : '
      WRITE(numout,*) ' ~~~~~~~~~~~~ '
      WRITE(numout,*) 

!
!-------------------------------------------------------------------------------
! 2) Initialize total mass
!-------------------------------------------------------------------------------
!
      zmt_i_00 = rhog * old_ht_i_b(ji) * a_tank + rho0 * v_w 
!
!-------------------------------------------------------------------------------
! 3) Update tank volume & salinity
!-------------------------------------------------------------------------------
!
      ! water volume
      zdh    = ht_i_b(ji) - old_ht_i_b(ji)       ! thickness change
      
      zdv_w  = - rhog / rho0 * a_tank * zdh      ! water volume change

      v_w    = v_w + zdv_w                       ! update water volume

      ! salinity
      zdms_w = - dms_i                           ! change of mass of salt in the ice
      
      ms_w   = ms_w + zdms_w                     ! update mass of salt in water

      s_w    = ms_w / rho0 / v_w * 1000.         ! recompute salinity

      WRITE(numout,*) ' rho0  : ' , rho0
      WRITE(numout,*) ' rhog  : ' , rhog
      WRITE(numout,*) ' zdh   : ' , zdh
      WRITE(numout,*) ' zdv_w : ' , zdv_w
      WRITE(numout,*) ' v_w   : ' , v_w
      WRITE(numout,*) ' h_w   : ' , v_w / a_tank
      WRITE(numout,*) ' zdms_w: ' , zdms_w 
      WRITE(numout,*) ' ms_w  : ' , ms_w 
      WRITE(numout,*) ' s_w   : ' , s_w  

!
!-------------------------------------------------------------------------------
! 4) Check mass conservation
!-------------------------------------------------------------------------------
!
      zmt_i_99 = rhog * ht_i_b(ji) * a_tank + rho0 * v_w 

      WRITE(numout,*) ' zmt_i_00 : ', zmt_i_00
      WRITE(numout,*) ' zmt_i_99 : ', zmt_i_99
         
!
!===============================================================================
!- end of wat_tank
      END SUBROUTINE wat_tank
